@@ -643,9 +643,9 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     # If it's a shared utils repo, need to reach down into this app's directory
     if os.path.isdir(APP_UTILS_DIR):
         with lcd(APP_UTILS_DIR+"/"):
-            local('git archive %s --format=tar.gz --output=../%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR)) 
+            local('git archive %s --format=tar.gz --output=../%s.tar.gz %s %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR, CERTS_DIR)) 
     else:
-        local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR))
+        local('git archive %s --format=tar.gz --output=%s.tar.gz %s %s %s %s' % (branch, TAR_NAME, CONFIG_DIR, ENV_DIR, KEY_DIR, CERTS_DIR))
 
 
     # and move the tarball to the destination and expand it
